from os import environ
from emailverifier import Client
from emailverifier.exceptions import ApiBaseException

from flask import current_app, _app_ctx_stack

CONFIG_KEY = "EMAIL_VERIFIER_KEY"


class EmailVerifier(object):
    def __init__(self, app=None):
        self.app = app
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        api_key = app.config.get(CONFIG_KEY) or environ.get(CONFIG_KEY)
        if not api_key:
            raise Exception("""No API key was supplied for performing email verification. 
            Please set a value for EMAIL_VERIFIER_KEY.""")

        self.client = Client(api_key)

    def verify(self, email, options=None):
        try:
            data = self.client.get(email, options)
        except ApiBaseException:
            data = None

        return data



from os.path import abspath, dirname, join, normpath

from setuptools import setup


setup(
    name="Flask-EmailVerifier",
    version="0.1.0",
    url="https://github.com/whois-api-llc/flask-email-verifier",
    license="MIT",
    author="Whois API, Inc.",
    author_email="support@whoisxmlapi.com",
    description="The simplest library for email verification for Flask.",
    long_description=open(normpath(join(dirname(abspath(__file__)), "README.rst"))).read(),
    py_modules=["flask_email_verifier"],
    zip_safe=False,
    include_package_data=True,
    platforms="any",
    install_requires=["Flask", "email-verifier"],
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules"
    ]
)
